@@ -44,20 +44,16 @@ Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 // -----------------------------------------------------------------------
 
 const NS_APP_CACHE_PARENT_DIR = "cachePDir";
+const XRE_UPDATE_ROOT_DIR     = "UpdRootD";
+const ENVVAR_UPDATE_DIR       = "UPDATES_DIRECTORY";
 
 function DirectoryProvider() {}
 
 DirectoryProvider.prototype = {
-  classDescription: "Directory Provider for special browser folders and files",
-  contractID: "@mozilla.org/browser/directory-provider;1",
   classID: Components.ID("{ef0f7a87-c1ee-45a8-8d67-26f586e46a4b}"),
   
   QueryInterface: XPCOMUtils.generateQI([Ci.nsIDirectoryServiceProvider]),
 
-  _xpcom_categories: [
-    { category: "xpcom-directory-providers", entry: "browser-directory-provider" }
-  ],
-
   getFile: function(prop, persistent) {
     if (prop == NS_APP_CACHE_PARENT_DIR) {
       let dirsvc = Cc["@mozilla.org/file/directory_service;1"].getService(Ci.nsIProperties);
@@ -66,7 +62,7 @@ DirectoryProvider.prototype = {
       let sysInfo = Cc["@mozilla.org/system-info;1"].getService(Ci.nsIPropertyBag2);
       let device = sysInfo.get("device");
       switch (device) {
-//@line 70 "/home/cltbld/build/maemo-lorentz-nightly/firefox-lorentz/mobile/components/DirectoryProvider.js"
+//@line 66 "/home/cltbld/build/mozilla-2.1-mob-maemo5-gtk/mozilla-2.1/mobile/components/DirectoryProvider.js"
         case "Nokia N900":
           return profile;
         
@@ -74,10 +70,22 @@ DirectoryProvider.prototype = {
           let folder = Cc["@mozilla.org/file/local;1"].createInstance(Ci.nsILocalFile);
           folder.initWithPath("/media/mmc2/.mozilla/fennec");
           return folder;
-//@line 78 "/home/cltbld/build/maemo-lorentz-nightly/firefox-lorentz/mobile/components/DirectoryProvider.js"
+//@line 74 "/home/cltbld/build/mozilla-2.1-mob-maemo5-gtk/mozilla-2.1/mobile/components/DirectoryProvider.js"
         default:
           return profile;
       }
+    } else if (prop == XRE_UPDATE_ROOT_DIR) {
+      let env = Cc["@mozilla.org/process/environment;1"].getService(Ci.nsIEnvironment);
+      if (env.exists(ENVVAR_UPDATE_DIR)) {
+        let path = env.get(ENVVAR_UPDATE_DIR);
+        if (path) {
+          let localFile = Cc["@mozilla.org/file/local;1"].createInstance(Ci.nsILocalFile);
+          localFile.initWithPath(path);
+          return localFile;
+        }
+      }
+      let dm = Cc["@mozilla.org/download-manager;1"].getService(Ci.nsIDownloadManager);
+      return dm.defaultDownloadsDirectory;
     }
     
     // We are retuning null to show failure instead for throwing an error. The
@@ -87,7 +95,5 @@ DirectoryProvider.prototype = {
   }
 };
 
-function NSGetModule(aCompMgr, aFileSpec) {
-  return XPCOMUtils.generateModule([DirectoryProvider]);
-}
+const NSGetFactory = XPCOMUtils.generateNSGetFactory([DirectoryProvider]);
 
